package controleurs;

import com.fasterxml.jackson.databind.ObjectMapper;
import dao.FilDAO;
import dao.MessageDAO;
import dao.UtilisateurDAO;
import io.jsonwebtoken.Claims;
import jakarta.servlet.http.*;
import jakarta.servlet.annotation.WebServlet;
import java.io.IOException;
import java.io.PrintWriter;
import java.nio.charset.StandardCharsets;
import java.util.*;
import dto.Fil;
import dto.Message;
import dto.Utilisateur;

@WebServlet("/filUser")
public class APIRest extends HttpServlet {

    private boolean verifToken(HttpServletRequest req) {

        String authorization = req.getHeader("Authorization");
        if (authorization == null || !authorization.startsWith("Bearer")) {
            return false;
        }

        String token = authorization.substring("Bearer".length()).trim();
        try {
            Claims claims = JwtManager.decodeJWT(token);
            req.setAttribute("login", claims.getSubject());
            return true;
        } catch (Exception e) {
            System.err.println("Token pas valide ! : " + e.getMessage());
            return false;
        }
    }

    public void doGet(HttpServletRequest req, HttpServletResponse res)
            throws IOException {
        res.setContentType("application/json;charset=UTF-8");
        PrintWriter out = res.getWriter();
        if (!verifToken(req)) {
            res.setStatus(HttpServletResponse.SC_UNAUTHORIZED);
            out.println("Erreur !! Le token n'est pas reconnu");
        } else {
            FilDAO filDAO = new FilDAO();
            MessageDAO messageDAO = new MessageDAO();
            UtilisateurDAO utilisateurDAO = new UtilisateurDAO();
            out.println("La vérification à fonctionnée !! Le token existe");

            res.setContentType("application/json;charset=UTF-8");
            ObjectMapper objectMapper = new ObjectMapper();
            String login = (String) req.getAttribute("login");
            int userId = utilisateurDAO.getUserIdByEmail(login);

            Collection<Fil> fils = filDAO.getFilsByUser(userId);
            List<Map<String, Object>> filsList = new ArrayList<>();

            for (Fil fil : fils) {
                List<Message> messages = messageDAO.getLastMessages(fil.getFid());
                Map<String, Object> filData = new HashMap<>();
                filData.put("id", fil.getFid());
                filData.put("titre", fil.getTitre());

                List<Map<String, Object>> messagesList = new ArrayList<>();
                for (Message msg : messages) {
                    Map<String, Object> msgData = new HashMap<>();
                    msgData.put("id", msg.getMid());
                    msgData.put("auteurId", msg.getUid());

                    if (msg.isImage()) {
                        Utilisateur user = utilisateurDAO.getUserById(msg.getUid());
                        msgData.put("message",
                                "Ceci est une image envoyé par " + user.getPrenom() + " " + user.getNom());
                    } else {
                        msgData.put("message", new String(msg.getMessageData(), StandardCharsets.UTF_8));
                    }

                    msgData.put("is_image", msg.isImage());
                    msgData.put("date", msg.getDateMessage().toString());

                    messagesList.add(msgData);
                }
                filData.put("messages", messagesList);
                filsList.add(filData);
            }
            String jsonstring = objectMapper.writerWithDefaultPrettyPrinter().writeValueAsString(filsList);
            out.println(jsonstring);
            return;
        }
        out.close();
    }
}
