package controleurs;

import dao.ParticipantFilDAO;
import dao.UtilisateurDAO;
import dto.Utilisateur;
import jakarta.servlet.annotation.WebServlet;
import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSession;
import org.apache.tomcat.jakartaee.commons.lang3.StringEscapeUtils;
import java.io.IOException;
import java.util.Arrays;
import java.util.List;

@WebServlet("/addUserFil")
public class FilAddUser extends HttpServlet {
    protected void doPost(HttpServletRequest req, HttpServletResponse res) throws IOException {
        res.setContentType("text/html;charset=UTF-8");
        HttpSession session = req.getSession(true);
        ParticipantFilDAO participantFilDAO = new ParticipantFilDAO();
        UtilisateurDAO utilisateurDAO = new UtilisateurDAO();

        Utilisateur u = (Utilisateur) session.getAttribute("utilisateur");

        if (u == null || u.getId() == 0) {
            res.sendRedirect("login.html");
            return;
        }

        String filIdParam = req.getParameter("filId");
        if (filIdParam == null || filIdParam.isEmpty()) {
            res.sendRedirect("Menu");
            return;
        }

        int filId;
        try {
            filId = Integer.parseInt(filIdParam);
        } catch (NumberFormatException e) {
            res.sendRedirect("Menu");
            return;
        }

        String utilisateurs = req.getParameter("utilisateurs");
        if (utilisateurs == null || utilisateurs.isEmpty()) {
            res.sendRedirect("Menu?filId=" + filId);
            return;
        }

        boolean admin = Boolean.parseBoolean(req.getParameter("admin"));

        if (!participantFilDAO.isAdmin(u, filId)) {
            res.sendRedirect("Menu?filId=" + filId);
            return;
        }

        List<String> users = Arrays.stream(utilisateurs.split("/"))
                .map(StringEscapeUtils::escapeHtml4)
                .map(String::trim)
                .filter(email -> !email.isEmpty())
                .toList();

        for (String email : users) {
            int userId = utilisateurDAO.getUserIdByEmail(email);
            if (userId != -1) {
                participantFilDAO.addParticipant(userId, filId, admin);
            }
        }

        res.sendRedirect("Menu?filId=" + filId);
    }
}
