package controleurs;

import java.io.IOException;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;
import dao.FilDAO;
import dto.Utilisateur;
import jakarta.servlet.http.*;
import jakarta.servlet.annotation.WebServlet;
import org.apache.tomcat.jakartaee.commons.lang3.StringEscapeUtils;

@WebServlet("/CreateFil")
public class FilCreate extends HttpServlet {

    protected void doPost(HttpServletRequest req, HttpServletResponse res) throws IOException {
        res.setContentType("text/html;charset=UTF-8");
        HttpSession session = req.getSession(true);

        Utilisateur u = (Utilisateur) session.getAttribute("utilisateur");
        if (u == null || u.getId() == 0) {
            res.sendRedirect("login.html");
            return;
        }

        int uid = u.getId();

        String titre = StringEscapeUtils.escapeHtml4(req.getParameter("titre"));
        String utilisateurs = StringEscapeUtils.escapeHtml4(req.getParameter("utilisateurs"));

        if (titre == null || titre.isEmpty() || utilisateurs == null || utilisateurs.isEmpty()) {
            res.sendRedirect("Menu");
            return;
        }

        boolean admin = Boolean.parseBoolean(req.getParameter("admin"));

        List<String> users = Arrays.stream(utilisateurs.split("/"))
                .map(String::trim)
                .filter(email -> !email.isEmpty())
                .collect(Collectors.toList());

        if (users.isEmpty()) {
            res.sendRedirect("Menu");
            return;
        }

        FilDAO filDAO = new FilDAO();
        int fid = filDAO.addFil(uid, titre, users, admin);

        if (fid != -1) {
            res.sendRedirect("Menu?filId=" + fid);
        } else {
            res.sendRedirect("Menu");
        }
    }
}
