package controleurs;

import java.io.IOException;
import java.util.List;
import dao.FilDAO;
import dao.ParticipantFilDAO;
import dto.Fil;
import dto.Utilisateur;
import jakarta.servlet.*;
import jakarta.servlet.http.*;
import jakarta.servlet.annotation.WebServlet;
import org.apache.tomcat.jakartaee.commons.lang3.StringEscapeUtils;

@WebServlet("/UserFil")
public class FilUser extends HttpServlet {
    private ParticipantFilDAO participantFilDAO = new ParticipantFilDAO();
    private FilDAO filDAO = new FilDAO();

    protected void doGet(HttpServletRequest req, HttpServletResponse res)
            throws ServletException, IOException {
        res.setContentType("text/html;charset=UTF-8");
        HttpSession session = req.getSession(true);
        Utilisateur utilisateur = (Utilisateur) session.getAttribute("utilisateur");

        if (utilisateur == null) {
            res.sendRedirect("login.html");
            return;
        }

        List<Fil> fils = filDAO.getFilsByUser(utilisateur.getId());
        req.setAttribute("fils", fils);
        String filIdParam = req.getParameter("filId");
        if (filIdParam != null && !filIdParam.isEmpty()) {
            filIdParam = StringEscapeUtils.escapeHtml4(filIdParam);

            try {
                int filId = Integer.parseInt(filIdParam);
                if (participantFilDAO.partFil(filId, utilisateur.getId())) {
                    req.setAttribute("filId", filIdParam);
                    List<Utilisateur> liste = participantFilDAO.getUsersByFilId(filId);
                    req.setAttribute("listeUsers", liste);
                }
            } catch (NumberFormatException e) {
                res.sendRedirect("Menu");
                return;
            }
        }
        req.getRequestDispatcher("addUser.jsp").forward(req, res);
    }

    protected void doPost(HttpServletRequest req, HttpServletResponse res) throws IOException {
        String userIdString = req.getParameter("userId");
        String filIdString = req.getParameter("filId");
        if (userIdString != null && filIdString != null && !userIdString.isEmpty() && !filIdString.isEmpty()) {
            userIdString = StringEscapeUtils.escapeHtml4(userIdString);
            filIdString = StringEscapeUtils.escapeHtml4(filIdString);

            try {
                int userId = Integer.parseInt(userIdString);
                int filId = Integer.parseInt(filIdString);
                participantFilDAO.deleteUserById(userId, filId);
                res.sendRedirect("Menu?filId=" + filIdString);
            } catch (NumberFormatException e) {
                res.sendRedirect("Menu");
            }
        } else {
            res.sendRedirect("Menu");
        }
    }
}
