package controleurs;

import dao.LikeDAO;
import jakarta.servlet.ServletException;
import jakarta.servlet.annotation.WebServlet;
import jakarta.servlet.http.HttpServlet;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSession;
import dto.Utilisateur;
import org.apache.tomcat.jakartaee.commons.lang3.StringEscapeUtils;

import java.io.IOException;

@WebServlet("/ControleurLike")
public class LikeControler extends HttpServlet {
    private static final long serialVersionUID = 1L;
    private LikeDAO likeDAO;

    @Override
    public void init() throws ServletException {
        super.init();
        likeDAO = new LikeDAO();
    }

    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws IOException {
        response.setContentType("text/html;charset=UTF-8");
        HttpSession session = request.getSession(true);

        String messIdParam = request.getParameter("messId");
        String fidParam = request.getParameter("fid");

        if (messIdParam == null || messIdParam.isEmpty() || fidParam == null || fidParam.isEmpty()) {
            response.sendRedirect("Menu");
            return;
        }

        messIdParam = StringEscapeUtils.escapeHtml4(messIdParam);
        fidParam = StringEscapeUtils.escapeHtml4(fidParam);

        int mid;
        int fid;

        try {
            mid = Integer.parseInt(messIdParam);
            fid = Integer.parseInt(fidParam);
        } catch (NumberFormatException e) {
            response.sendRedirect("Menu");
            return;
        }

        Utilisateur user = (Utilisateur) session.getAttribute("utilisateur");

        if (user == null || user.getId() == 0) {
            response.sendRedirect("login.html");
            return;
        }

        boolean hasLiked = likeDAO.hasLiked(mid, user.getId());

        if (hasLiked) {
            likeDAO.removeLike(mid, user.getId());
        } else {
            likeDAO.addLike(mid, user.getId());
        }

        response.sendRedirect("Menu?filId=" + fid);
    }
}
