package controleurs;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import dao.MessageDAO;
import dto.Utilisateur;
import jakarta.servlet.*;
import jakarta.servlet.annotation.MultipartConfig;
import jakarta.servlet.http.*;
import jakarta.servlet.annotation.WebServlet;
import org.apache.tomcat.jakartaee.commons.lang3.StringEscapeUtils;

@MultipartConfig(fileSizeThreshold = 1024 * 1024, maxFileSize = 1024 * 1024 * 10, maxRequestSize = 1024 * 1024 * 50)
@WebServlet("/EnvoyerMessage")
public class MessageSend extends HttpServlet {
    private static final long serialVersionUID = 1L;
    private MessageDAO messageDAO;

    @Override
    public void init() throws ServletException {
        super.init();
        messageDAO = new MessageDAO();
    }

    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        String fidParam = request.getParameter("fid");
        String uidParam = request.getParameter("uid");

        if (fidParam == null || fidParam.isEmpty() || uidParam == null || uidParam.isEmpty()) {
            response.sendRedirect("Menu");
            return;
        }

        int fid = -1;
        int uid = -1;

        try {
            fid = Integer.parseInt(fidParam);
            uid = Integer.parseInt(uidParam);
        } catch (NumberFormatException e) {
            response.sendRedirect("Menu");
            return;
        }

        String message = StringEscapeUtils.escapeHtml4(request.getParameter("message"));

        HttpSession session = request.getSession(true);
        Utilisateur user = (Utilisateur) session.getAttribute("utilisateur");

        if (user == null || user.getId() == 0) {
            response.sendRedirect("login.html");
            return;
        }

        Part imagePart = request.getPart("image");
        boolean isImage = false;
        byte[] imageData = null;

        if (imagePart != null && imagePart.getSize() > 0) {
            imageData = imagePart.getInputStream().readAllBytes();
            isImage = true;
        }

        if ((message == null || message.isEmpty()) && isImage) {
            message = "message vide";
        } else if (message == null || message.isEmpty()) {
            response.sendRedirect("Menu?filId=" + fid);
            return;
        }
        if (message != null && !message.trim().isEmpty()) {
            if (isImage) {
                messageDAO.addMessage(fid, uid, imageData, true);
            } else {
                messageDAO.addMessage(fid, uid, message.getBytes(StandardCharsets.UTF_8), false);
            }
        }
        response.sendRedirect("Menu?filId=" + fid);
    }
}
