package dao;

import java.sql.*;
import java.time.LocalDateTime;
import java.time.ZoneId;
import java.util.ArrayList;
import java.util.List;
import java.sql.Timestamp;
import dto.Message;
import java.time.LocalDate;

public class MessageDAO {
    private final DS ds;

    public MessageDAO() {
        this.ds = new DS();
    }

    public List<Message> getLastMessages(int id_fil) {
        List<Message> messages = new ArrayList<>();
        String query = "SELECT * FROM message WHERE f_id = ? ORDER BY DateMessage ASC";

        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ps.setInt(1, id_fil);
            ResultSet rs = ps.executeQuery();

            while (rs.next()) {
                Message mess = new Message(
                        rs.getInt("m_id"),
                        rs.getInt("f_id"),
                        rs.getInt("u_id"),
                        rs.getBytes("message_data"),
                        rs.getBoolean("is_image"),
                        rs.getInt("d_vie"),
                        rs.getTimestamp("DateMessage"));
                messages.add(mess);
            }
        } catch (SQLException e) {
            System.err.println("Erreur lors de la récupération des messages : " + e.getMessage());
        }
        return messages;
    }

    public boolean addMessage(int fid, int uid, byte[] data, boolean isImage) {
        String query = "INSERT INTO message (f_id, u_id, message_data, is_image, d_vie, DateMessage) VALUES (?, ?, ?, ?, ?, ?)";
        boolean success = false;

        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ps.setInt(1, fid);
            ps.setInt(2, uid);
            ps.setBytes(3, data);
            ps.setBoolean(4, isImage);
            ps.setInt(5, Integer.parseInt(ConfigLoader.getProperty("nbday")));
            ps.setTimestamp(6, Timestamp.valueOf(LocalDateTime.now()));

            int result = ps.executeUpdate();
            success = result > 0;
        } catch (Exception e) {
            System.err.println("Erreur lors de l'ajout du message : " + e.getMessage());
        }
        return success;
    }

    public void checkTimeMessage() {
        String query = "SELECT * FROM message";
        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ResultSet rs = ps.executeQuery();
            while (rs.next()) {
                LocalDate dateMessage = rs.getTimestamp("datemessage").toInstant().atZone(ZoneId.systemDefault())
                        .toLocalDate().plusDays(rs.getInt("d_vie"));
                LocalDate dateLimite = LocalDate.now();
                if (dateMessage.isBefore(dateLimite)) {
                    deleteMessage(rs.getInt("m_id"));
                }
            }

        } catch (Exception e) {
            System.err.println("Erreur lors de la vérification des messages : " + e.getMessage());
        }
    }

    public void deleteMessage(int mId) {
        String query = "DELETE from message where m_id = ?";
        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ps.setInt(1, mId);
            ps.executeUpdate();
        } catch (Exception e) {
            System.err.println("Erreur lors de la suppression du message : " + e.getMessage());
        }
    }
}
