package dao;

import dto.Utilisateur;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

public class ParticipantFilDAO {
    private final DS ds;

    public ParticipantFilDAO() {
        this.ds = new DS();
    }

    public void addParticipant(int userId, int filId, boolean administrateur) {
        String insertParticipantQuery = "INSERT INTO participant_fil (up_id, fp_id, administrateur) VALUES (?, ?, ?);";

        try (Connection con = ds.getConnection();
                PreparedStatement psParticipant = con.prepareStatement(insertParticipantQuery)) {
            psParticipant.setInt(1, userId);
            psParticipant.setInt(2, filId);
            psParticipant.setBoolean(3, administrateur);
            psParticipant.executeUpdate();
        } catch (SQLException e) {
            System.err.println(e.getMessage());
        }
    }

    public boolean isAdmin(dto.Utilisateur u, int filId) {
        int userId = u.getId();
        String query = "SELECT administrateur FROM participant_fil WHERE up_id = ? AND fp_id = ?";

        try (Connection conn = ds.getConnection();
                PreparedStatement stmt = conn.prepareStatement(query)) {
            stmt.setInt(1, userId);
            stmt.setInt(2, filId);
            try (ResultSet rs = stmt.executeQuery()) {
                if (rs.next()) {
                    return rs.getString("administrateur").equals("t");
                } else {
                    return false;
                }
            }
        } catch (SQLException e) {
            System.err.println(e.getMessage());
            return false;
        }
    }

    public List<dto.Utilisateur> getUsersByFilId(int filId) {
        String query = "SELECT u.* FROM UTILISATEUR AS u JOIN PARTICIPANT_FIL AS participant ON u.U_ID = participant.UP_ID WHERE participant.FP_ID = ?";
        try (Connection con = ds.getConnection();) {
            PreparedStatement ps = con.prepareStatement(query);
            ps.setInt(1, filId);
            ResultSet rs = ps.executeQuery();
            List<dto.Utilisateur> liste = new ArrayList<>();
            while (rs.next()) {
                liste.add(new Utilisateur(rs.getInt("u_id"), rs.getString("mail"), rs.getString("nom"),
                        rs.getString("prenom")));
            }
            return liste;
        } catch (Exception e) {
            System.err.println(e.getMessage());
            return null;
        }
    }

    public void deleteUserById(int userId, int filId) {
        String query = "Delete from participant_fil where up_id = ? and fp_id = ?";
        try (Connection con = ds.getConnection()) {
            PreparedStatement ps = con.prepareStatement(query);
            ps.setInt(1, userId);
            ps.setInt(2, filId);
            ResultSet rs = ps.executeQuery();
            rs.next();
        } catch (Exception e) {
            System.err.println(e.getMessage());
        }
    }

    public boolean partFil(int fid, int uid) {
        String query = "SELECT 1 FROM participant_fil WHERE fp_id = ? AND up_id = ?";
        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ps.setInt(1, fid);
            ps.setInt(2, uid);
            ResultSet rs = ps.executeQuery();
            return rs.next();
        } catch (Exception e) {
            System.err.println(e.getMessage());
            return false;
        }
    }
}
