package dao;

import dto.Utilisateur;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

public class UtilisateurDAO {
    private final DS ds;

    public UtilisateurDAO() {
        ds = new DS();
    }

    public Utilisateur editUser(dto.Utilisateur user, String email, String nom, String prenom, String mdp) {
        String query = "UPDATE utilisateur SET mail = ?, nom = ?, prenom = ?, mdp = MD5(?) WHERE u_id = ?";
        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ps.setString(1, email);
            ps.setString(2, nom);
            ps.setString(3, prenom);
            ps.setString(4, mdp);
            ps.setInt(5, user.getId());
            int result = ps.executeUpdate();
            if (result > 0) {
                user.setEmail(email);
                user.setNom(nom);
                user.setPrenom(prenom);
            } else {
                System.err.println("Aucune modification effectuée (utilisateur introuvable).");
                return null;
            }
        } catch (Exception e) {
            System.err.println("Erreur lors de la modification des informations : " + e.getMessage());
            return null;
        }
        return user;
    }

    public boolean userExist(String mail) {
        String query = "SELECT mail FROM utilisateur WHERE mail = ?";
        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ps.setString(1, mail);
            ResultSet rs = ps.executeQuery();
            return rs.next();
        } catch (SQLException e) {
            System.err.println(e.getMessage());
            return false;
        }
    }

    public boolean addUser(Utilisateur utilisateur, String mdp) {
        String query = "INSERT INTO utilisateur(prenom, nom, mail, mdp) VALUES(?, ?, ?, MD5(?))";
        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(query)) {
            ps.setString(1, utilisateur.getPrenom());
            ps.setString(2, utilisateur.getNom());
            ps.setString(3, utilisateur.getEmail());
            ps.setString(4, mdp);
            return ps.executeUpdate() > 0;
        } catch (SQLException e) {
            System.err.println(e.getMessage());
            return false;
        }
    }

    public Utilisateur checkUser(String email, String mdp) {
        Utilisateur utilisateur = null;
        try (Connection con = ds.getConnection();) {
            String query = "SELECT * FROM UTILISATEUR WHERE mail = ? AND mdp = MD5(?)";
            PreparedStatement ps = con.prepareStatement(query);
            ps.setString(1, email);
            ps.setString(2, mdp);
            ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                utilisateur = new Utilisateur(rs.getInt("U_ID"), rs.getString("mail"), rs.getString("nom"),
                        rs.getString("prenom"));
            }
        } catch (Exception e) {
            System.err.println(e.getMessage());
        }
        return utilisateur;
    }

    public Utilisateur getUserById(int id) {
        Utilisateur result = null;
        try (Connection con = ds.getConnection();) {
            String query = "SELECT prenom, nom, mail FROM UTILISATEUR WHERE u_id = ?";
            PreparedStatement ps = con.prepareStatement(query);
            ps.setInt(1, id);
            ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                result = new Utilisateur(id, rs.getString("mail"), rs.getString("nom"), rs.getString("prenom"));
            }
        } catch (Exception e) {
            System.err.println(e.getMessage());
        }
        return result;
    }

    public int getUserIdByEmail(String email) {
        String getUserIdQuery = "SELECT u_id FROM utilisateur WHERE mail = ?;";
        int userId = -1;
        try (Connection con = ds.getConnection();
                PreparedStatement ps = con.prepareStatement(getUserIdQuery)) {
            ps.setString(1, email);
            ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                userId = rs.getInt("u_id");
            }
        } catch (SQLException e) {
            System.err.println(e.getMessage());
        }
        return userId;
    }
}